@@ -33,12 +33,14 @@ sub _item_name_plural { 'options' }
 *add_options = \&Rose::HTML::Form::Field::Group::add_items;
 *add_option  = \&Rose::HTML::Form::Field::Group::add_item;
 
+*choices = \&options;
+
 *_args_to_items = \&Rose::HTML::Form::Field::Group::_args_to_items;
 
 sub html_element  { 'select' }
 sub xhtml_element { 'select' }
 
-sub name { shift->html_attr('name', @_) }
+#sub name { shift->html_attr('name', @_) }
 
 sub html_field
 {
