@@ -11,7 +11,7 @@ use Rose::Object::MakeMethods::Generic
   boolean => 'multiple',
 );
 
-our $VERSION = '0.011';
+our $VERSION = '0.50';
 
 __PACKAGE__->add_required_html_attrs(
 {
@@ -125,6 +125,10 @@ Convenience alias for L<add_options()|/add_options>.
 
 Adds options to the option group.  OPTIONS may be a reference to a hash of value/label pairs, a reference to an array of values, or a list of L<Rose::HTML::Form::Field::Option> objects. Passing an odd number of items in the value/label argument list causes a fatal error. Options passed as a hash reference are sorted by value according to the default behavior of Perl's built-in L<sort()|perlfunc/sort> function.  Options are added to the end of the existing list of options.
 
+=item B<choices [OPTIONS]>
+
+This is an alias for the L<options|/options> method.
+
 =item B<has_value VALUE>
 
 Returns true if VALUE is selected in the option group, false otherwise.
@@ -171,4 +175,4 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2006 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
